import { type ZodSchema, z } from 'zod';
/**
 * A helper function to parse a JSON string and validate it against a schema.
 * Use it for built-in schemas like `AlbSchema`, `ApiGatewaySchema`, etc. to extend them with your customer schema.
 *
 * @example
 * ```typescript
 * import { JSONStringified } from '@aws-lambda-powertools/parser/helpers';
 * import { AlbSchema } from '@aws-lambda-powertools/parser/schemas';
 * import { z } from 'zod';
 *
 * const customSchema = z.object({
 *   name: z.string(),
 *   age: z.number(),
 * });
 *
 * const extendedSchema = AlbSchema.extend({
 *   body: JSONStringified(customSchema),
 * });
 *
 * ```
 *
 * @param schema - The schema to validate the JSON string against
 */
declare const JSONStringified: (schema: ZodSchema) => z.ZodPipeline<z.ZodEffects<z.ZodString, any, string>, ZodSchema<any, z.ZodTypeDef, any>>;
export { JSONStringified };
//# sourceMappingURL=helpers.d.ts.map